Learn R Programming

plsRbeta (version 0.2.6)

summary.plsRbetamodel: Summary method for plsRbeta models

Description

This function provides a summary method for the class "plsRbetamodel"

Usage

# S3 method for plsRbetamodel
summary(object, ...)

Arguments

object

an object of the class "plsRbetamodel"

further arguments to be passed to or from methods.

Value

call

function call of plsR beta models

References

Fr<U+00E9>d<U+00E9>ric Bertrand, Nicolas Meyer, Mich<U+00E8>le Beau-Faller, Karim El Bayed, Izzie-Jacques Namer, Myriam Maumy-Bertrand (2013). R<U+00E9>gression B<U+00EA>ta PLS. Journal de la Soci<U+00E9>t<U+00E9> Fran<U+00E7>aise de Statistique, 154(3):143-159. http://publications-sfds.math.cnrs.fr/index.php/J-SFdS/article/view/215

See Also

summary

Examples

Run this code
# NOT RUN {
data("GasolineYield",package="betareg")
modpls <- plsRbeta(yield~.,data=GasolineYield,nt=3,modele="pls-beta")
summary(modpls)

# }

Run the code above in your browser using DataLab